@@ -14,6 +14,7 @@ import Control.Monad.Compat ()
 import Control.Monad.Fail.Compat ()
 import Control.Monad.IO.Class.Compat ()
 import Data.Bifoldable.Compat ()
+import Data.Bifoldable1.Compat ()
 import Data.Bifunctor.Compat ()
 import Data.Bitraversable.Compat ()
 import Data.Bits.Compat ()
@@ -21,6 +22,7 @@ import Data.Bool.Compat ()
 import Data.Complex.Compat ()
 import Data.Either.Compat ()
 import Data.Foldable.Compat ()
+import Data.Foldable1.Compat ()
 import Data.Function.Compat ()
 import Data.Functor.Compat ()
 import Data.Functor.Compose.Compat ()
@@ -38,7 +40,9 @@ import Data.Ratio.Compat ()
 import Data.Semigroup.Compat ()
 import Data.STRef.Compat ()
 import Data.String.Compat ()
+import Data.Traversable.Compat ()
 import Data.Tuple.Compat ()
+import Data.Typeable.Compat ()
 import Data.Type.Coercion.Compat ()
 import Data.Type.Equality.Compat ()
 import Data.Version.Compat ()
